@@ -71,16 +71,6 @@ def test_noblanks_false():
      '',
      '']
     
-def test_malindented_blank_lines():
-    
-    assert textlines(noblanks=False, text="""
-        this
-
-        is
-        ok
-
-    """) == "this\n\nis\nok\n"
-    
 def test_extra_start_space():
     
     single_trial('test2', """
@@ -101,7 +91,7 @@ def test_extra_start_space():
      "  which isn't common"]
 
 def test_textlines():
-    data = """
+    lresult = lines("""
                 
                 
     This is a test of lines
@@ -112,29 +102,19 @@ def test_textlines():
       
 
     
-          """
+          """)
     
-    assert lines(data) == textlines(data).splitlines()
-    assert lines(data, join=True) == lines(data, join='')
-    assert lines(data, join=True) == ''.join(textlines(data).splitlines())
-    assert lines(data, join=' ') == ' '.join(textlines(data).splitlines())
-    assert lines(data, join='\n') == textlines(data)
-    assert len(lines(data)) == 4
+    tresult = textlines("""
+                
+                
+    This is a test of lines
     
-def test_tricky_prefix():
-    """
-    Common prefixes need not be all spaces. This tests if common non-blank
-    prefixes are properly handled.
-    """
+    here there should be no blanks
+     but some that start wiht a little extra space ok?
+      which isn't common
+      
+
     
-    t = textlines("""
-        something
-        something else
-    """)
-    assert t == "something\nsomething else"
+          """)
     
-    t2 = textlines("""
-xxx y
-xxx z
-""")
-    assert t2 == "xxx y\nxxx z"
\ No newline at end of file
+    assert lresult == tresult.splitlines()
\ No newline at end of file
